ApiDocAttribute Type
Represents a custom attribute attached to source code
Constructors
| Constructor |
Description
|
Instance members
| Instance member |
Description
|
|
|
|
Returns the custom operation name, when this attribute is the CustomOperationAttribute. When its not an empty string is returned
|
|
Formats the attribute using the Name. Removes the "Attribute"-suffix. E.g Obsolete
|
|
Formats the attribute using the FullName. Removes the "Attribute"-suffix. E.g System.Obsolete
|
|
Formats the attribute using the FullName. Keeps the "Attribute"-suffix. E.g System.ObsoleteAttribute
|
|
Formats the attribute using the Name. Keeps the "Attribute"-suffix. E.g ObsoleteAttribute
|
|
The qualified name of the attribute
|
|
Gets a value indicating whether this attribute the CustomOperationAttribute
|
|
Gets a value indicating whether this attribute is System.ObsoleteAttribute
|
|
Gets a value indicating whether this attribute is RequireQualifiedAccessAttribute
|
The name of the attribute
|
|
|
|
|
Returns the obsolete message, when this attribute is the System.ObsoleteAttribute. When its not or no message was specified, an empty string is returned
|
FSharp.Formatting