ApiDocEntity Type
Represents a type definition integrated with its associated documentation
Constructors
Instance members
| Instance member |
Description
|
|
If this is a type abbreviation, then the abbreviated type
|
|
Active patterns of the module
|
|
All interfaces of the type, formatted
|
|
All members of the type
|
|
The name of the type's assembly
|
|
The declared attributes of the type
|
|
The base type of the type, formatted
|
|
The category of the type
|
Full Usage:
this.CategoryIndex
Returns: int
|
The category index of the type
|
|
The attached comment
|
|
The constuctorsof the type
|
|
If this is a delegate, then e formatted signature
|
|
The exclude flag
|
|
Members inherited from base types (grouped by base type, shown in docs as "Inherited from X")
|
|
The instance members of the type
|
|
Gets a value indicating whether this member is obsolete
|
|
Indicates if the entity is a type definition
|
The name of the entity
|
|
|
All nested modules and types
|
|
Returns the obsolete message, when this member is obsolete. When its not or no message was specified, an empty string is returned
|
|
|
|
The fields of a record type
|
|
Does the module have the RequiresQualifiedAccess attribute
|
|
|
|
The static members of the type
|
|
Static parameters
|
|
The substitution parameters active for generating thist content
|
|
The F# compiler symbol for the type definition
|
|
Type extensions of the module
|
|
The cases of a union type
|
|
The URL base name of the primary documentation for the entity (without the http://site.io/reference)
|
|
Values and functions of the module
|
Static members
| Static member |
Description
|
FSharp.Formatting