ApiDocInput Type
Represents an input assembly for API doc generation
Record fields
| Record Field |
Description
|
|
Whether the input uses markdown comments
|
The path to the assembly
|
|
|
Whether to generate only public things
|
|
Whether to show members inherited from documented base types. Defaults to true. Set to false to suppress "Inherited from X" sections.
|
|
|
|
|
|
The substitutionss active for this input. If specified these are used instead of the overall substitutions. This allows different parameters (e.g. different authors) for each assembly in a collection.
|
|
Controls how type constraints on generic members are displayed. Defaults to Short, which appends constraints inline as a 'when' clause.
|
Whether doc processing should warn on missing comments
|
|
Static members
| Static member |
Description
|
Full Usage:
ApiDocInput.FromFile(assemblyPath, ?mdcomments, ?substitutions, ?sourceRepo, ?sourceFolder, ?publicOnly, ?warn, ?showInheritedMembers, ?typeConstraintDisplayMode)
Parameters:
string
?mdcomments : bool
?substitutions : Substitutions
?sourceRepo : string
?sourceFolder : string
?publicOnly : bool
?warn : bool
?showInheritedMembers : bool
?typeConstraintDisplayMode : TypeConstraintDisplayMode
Returns: ApiDocInput
|
|
FSharp.Formatting