ApiDocModel Type
Represents a set of assemblies integrated with their associated documentation
Instance members
| Instance member |
Description
|
|
The full list of all entities
|
|
The full list of all entities
|
|
Specifies file extensions to use in files and URLs
|
|
|
|
Indicates if each collection is being qualified by its collection name, e.g. 'reference/FSharp.Core'
|
The root URL for the entire generation, normally '/'
|
|
|
The substitutions. Different substitutions can also be used for each specific input
|
FSharp.Formatting