Logo FSharp.Formatting

ToolTipSpan Type

A tool tip span can be emphasized text, plain text Literal, a classified Token or a line break

Union cases

Union case Description

Emphasis ToolTipSpans

Full Usage: Emphasis ToolTipSpans

Parameters:

HardLineBreak

Full Usage: HardLineBreak

Literal string

Full Usage: Literal string

Parameters:
Item : string

Token(kind, body)

Full Usage: Token(kind, body)

Parameters:

A run of tool tip text the compiler classified, rendered with the same colors as the equivalent token in a code snippet

kind : TokenKind
body : string

Type something to start searching.