Logo FSharp.Formatting

Logging Type

Configures where FSharp.Formatting logs. The libraries log through and are silent by default: set to your own factory, or call .

Static members

Static member Description

Logging.ConsoleSink(?timestamps)

Full Usage: Logging.ConsoleSink(?timestamps)

Parameters:
    ?timestamps : bool

Returns: LogSink

A sink writing information and below to standard output and warnings and errors to standard error, with a 'warning: ' or 'error: ' prefix and an optional timestamp.

?timestamps : bool
Returns: LogSink

Logging.LoggerFactory

Full Usage: Logging.LoggerFactory

Returns: ILoggerFactory

The factory used for all FSharp.Formatting loggers. Defaults to NullLoggerFactory.

Returns: ILoggerFactory

Logging.UseConsole(minimumLevel, ?timestamps)

Full Usage: Logging.UseConsole(minimumLevel, ?timestamps)

Parameters:

Log to the console: information and below on standard output, warnings and errors on standard error.

minimumLevel : LogLevel
?timestamps : bool

Logging.UseSink(minimumLevel, sink)

Full Usage: Logging.UseSink(minimumLevel, sink)

Parameters:

Log to the given sink.

minimumLevel : LogLevel
sink : LogSink

Type something to start searching.