Logo FSharp.Formatting

PageContentList Module

Builds a "page content" table-of-contents menu by scanning heading links in rendered HTML

Functions and values

Function or value Description

EmptyContent

Full Usage: EmptyContent

Returns: string

Placeholder HTML emitted when a page has no headings to list

Returns: string

mkPageContentMenu html

Full Usage: mkPageContentMenu html

Parameters:
Returns: string list * string * string

Returns the heading texts (for the search index), the menu HTML and the content HTML with the headings annotated with their index.

html : string
Returns: string list * string * string

scrollSpyStyle headingCount

Full Usage: scrollSpyStyle headingCount

Parameters:
    headingCount : int

Returns: string

The `

    Type something to start searching.