Logo FSharp.Formatting

JavaScriptFormat Type

Generates color-coded HTML 4.01 from JavaSctript source code.

Constructors

Constructor Description

JavaScriptFormat()

Full Usage: JavaScriptFormat()

Instance members

Instance member Description

this.Keywords

Full Usage: this.Keywords

Returns: string
Modifiers: abstract

The list of JavaScript keywords.

Returns: string

this.Operators

Full Usage: this.Operators

Returns: string
Modifiers: abstract

TBD

Returns: string

this.Preprocessors

Full Usage: this.Preprocessors

Returns: string
Modifiers: abstract

Use the pre-processor color to mark directives that start with @.

Returns: string

Inherited members

Inherited from CLikeFormat

Instance members

Instance member Description

this.CommentRegEx

Full Usage: this.CommentRegEx

Returns: string
Modifiers: abstract

Regular expression string to match single line and multi-line comments (// and /* */).

Returns: string

this.StringRegEx

Full Usage: this.StringRegEx

Returns: string
Modifiers: abstract

Regular expression string to match string and character literals.

Returns: string

Inherited from CodeFormat

Instance members

Instance member Description

this.Keywords

Full Usage: this.Keywords

Returns: string
Modifiers: abstract

Must be overridden to provide a list of keywords defined in each language.

Keywords must be separated with spaces.

Returns: string

this.Operators

Full Usage: this.Operators

Returns: string
Modifiers: abstract

Must be overridden to provide a list of operators defined in each language.

Operators must be separated with spaces.

Returns: string

this.Preprocessors

Full Usage: this.Preprocessors

Returns: string
Modifiers: abstract

Can be overridden to provide a list of preprocessors defined in each language.

Preprocessors must be separated with spaces.

Returns: string

this.StringRegEx

Full Usage: this.StringRegEx

Returns: string
Modifiers: abstract

Must be overridden to provide a regular expression string to match strings literals.

Returns: string

this.CommentRegEx

Full Usage: this.CommentRegEx

Returns: string
Modifiers: abstract

Must be overridden to provide a regular expression string to match comments.

Returns: string

this.NumberRegEx

Full Usage: this.NumberRegEx

Returns: string
Modifiers: abstract

Can be overridden to provide a list of tokes to be recognized as numbers.

Returns: string

this.CaseSensitive

Full Usage: this.CaseSensitive

Returns: bool
Modifiers: abstract

Determines if the language is case sensitive.

A case-insensitive language formatter must override this property to return false.

Returns: bool

Inherited from SourceFormat

Instance members

Instance member Description

this.FormatCode

Full Usage: this.FormatCode

Parameters:
    source : Stream - Source code stream.

Returns: string A string containing the HTML formatted code.

Transforms a source code stream to HTML 4.01.

source : Stream

Source code stream.

Returns: string

A string containing the HTML formatted code.

this.FormatCode

Full Usage: this.FormatCode

Parameters:
    source : string

Returns: string A string containing the HTML formatted code.

Transforms a source code string to HTML 4.01.

source : string
Returns: string

A string containing the HTML formatted code.

this.FormatSubCode

Full Usage: this.FormatSubCode

Parameters:
    source : string

Returns: string

Allows formatting a part of the code in a different language, for example a JavaScript block inside an HTML file.

source : string
Returns: string

this.TabSpaces

Full Usage: this.TabSpaces

Returns: byte

Gets or sets the tabs width.

Returns: byte

this.LineNumbers

Full Usage: this.LineNumbers

Returns: bool

Enables or disables line numbers in output.

Returns: bool

this.Alternate

Full Usage: this.Alternate

Returns: bool

Enables or disables alternating line background.

Returns: bool

this.EmbedStyleSheet

Full Usage: this.EmbedStyleSheet

Returns: bool

Enables or disables the embedded CSS style sheet.

Returns: bool

this.CodeRegex

Full Usage: this.CodeRegex

Returns: Regex

The regular expression used to capture language tokens.

Returns: Regex

Static members

Static member Description

SourceFormat.GetCssStream()

Full Usage: SourceFormat.GetCssStream()

Returns: Stream A text Stream of the CSS definitions.

Gets the CSS stylesheet as a stream.

Returns: Stream

A text Stream of the CSS definitions.

SourceFormat.GetCssString()

Full Usage: SourceFormat.GetCssString()

Returns: string A string containing the CSS definitions.

Gets the CSS stylesheet as a string.

Returns: string

A string containing the CSS definitions.

SourceFormat.EscapeHtml(str, tabSpaces)

Full Usage: SourceFormat.EscapeHtml(str, tabSpaces)

Parameters:
    str : string
    tabSpaces : int

Returns: string

TBD

str : string
tabSpaces : int
Returns: string

Type something to start searching.