SourceFormat Type
Provides a base implementation for all code formatters.
To display the formatted code on your web site, the web page must refer to a stylesheet that defines the formatting for the different CSS classes generated by CSharpFormat: .csharpcode, pre, .rem, .kwrd, .str, .op, .preproc, .alt, .lnum.
Note that if you have multi-line comments in your source code (like /* ... */), the "line numbers" or "alternate line background" options will generate code that is not strictly HTML 4.01 compliant. The code will still look good with IE5+ or Mozilla 0.8+.
Constructors
| Constructor |
Description
|
Full Usage:
SourceFormat()
|
|
Instance members
| Instance member |
Description
|
|
Enables or disables alternating line background.
|
|
The regular expression used to capture language tokens.
|
|
Enables or disables the embedded CSS style sheet.
|
|
|
|
|
|
|
|
Enables or disables line numbers in output.
|
|
Gets or sets the tabs width.
|
Static members
| Static member |
Description
|
|
|
|
|
|
Gets the CSS stylesheet as a string.
|
FSharp.Formatting