TypeScriptFormat Type
Generates color-coded HTML 4.01 from TypeScript source code.
Constructors
| Constructor |
Description
|
Full Usage:
TypeScriptFormat()
|
|
Instance members
| Instance member |
Description
|
|
The list of TypeScript keywords extends the ones from JavaScript.
|
Inherited members
Inherited from
JavaScriptFormat
Instance members
| Instance member |
Description
|
|
The list of JavaScript keywords.
|
|
Use the pre-processor color to mark directives that start with @.
|
|
TBD
|
Inherited from
CLikeFormat
Instance members
| Instance member |
Description
|
|
Regular expression string to match single line and multi-line comments (// and /* */).
|
|
Regular expression string to match string and character literals.
|
Inherited from
CodeFormat
Instance members
| Instance member |
Description
|
|
Must be overridden to provide a list of keywords defined in each language. Keywords must be separated with spaces.
|
|
Must be overridden to provide a list of operators defined in each language. Operators must be separated with spaces.
|
|
Can be overridden to provide a list of preprocessors defined in each language. Preprocessors must be separated with spaces.
|
|
Must be overridden to provide a regular expression string to match strings literals.
|
|
Must be overridden to provide a regular expression string to match comments.
|
|
Can be overridden to provide a list of tokes to be recognized as numbers.
|
|
Determines if the language is case sensitive. A case-insensitive language formatter must override this property to return false.
|
Inherited from
SourceFormat
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
|
Gets or sets the tabs width.
|
|
Enables or disables line numbers in output.
|
|
Enables or disables alternating line background.
|
|
Enables or disables the embedded CSS style sheet.
|
|
The regular expression used to capture language tokens.
|
Static members
| Static member |
Description
|
|
|
|
Gets the CSS stylesheet as a string.
|
|
FSharp.Formatting