FsiEvaluationResult Type
Represents the result of evaluating an F# snippet. This contains the generated console output together with a result and its static type.
Record fields
| Record Field |
Description
|
|
|
Represents the result of evaluating an F# snippet. This contains the generated console output together with a result and its static type.
| Record Field |
Description
|
|
|