FsiEvaluator Type
A wrapper for F# interactive service that is used to evaluate inline snippets
Constructors
| Constructor |
Description
|
Instance members
| Instance member |
Description
|
|
This event is fired whenever an evaluation of an expression fails
|
Full Usage:
this.RegisterTransformation
Parameters:
obj * Type * int -> MarkdownParagraph list option
|
Register a function that formats (some) values that are produced by the evaluator. The specified function should return 'Some' when it knows how to format a value and it should return formatted
|
FSharp.Formatting