MarkdownPatterns Module
This module provides an easy way of processing Markdown documents. It lets you decompose documents into leafs and nodes with nested paragraphs.
Types
| Type | Description |
|
Carries the identity of a leaf paragraph (no children) |
|
|
Carries the identity of a paragraph that contains nested paragraph lists |
|
|
Carries the identity of a paragraph that itself contains inline spans |
|
|
Carries the identity of a leaf span (one with no child spans) |
|
|
Carries the identity of a node span (one with child spans) |
Functions and values
| Function or value |
Description
|
|
|
Full Usage:
ParagraphNested (arg1, pars)
Parameters:
ParagraphNestedInfo
pars : MarkdownParagraphs list
Returns: MarkdownParagraph
|
Reconstructs a nested-paragraph container with an updated flat list of child paragraphs
|
Full Usage:
ParagraphSpans (arg1, spans)
Parameters:
ParagraphSpansInfo
spans : MarkdownSpans
Returns: MarkdownParagraph
|
Reconstructs a spans-container paragraph with an updated span list
|
|
|
Full Usage:
SpanNode (arg1, spans)
Parameters:
SpanNodeInfo
spans : MarkdownSpans
Returns: MarkdownSpan
|
Reconstructs a node span from its
|
Active patterns
| Active pattern |
Description
|
Full Usage:
(|ParagraphLeaf|ParagraphNested|ParagraphSpans|) par
Parameters:
MarkdownParagraph
Returns: Choice<ParagraphLeafInfo, (ParagraphNestedInfo * MarkdownParagraphs list), (ParagraphSpansInfo * MarkdownSpans)>
|
Active pattern that classifies a
|
Full Usage:
(|SpanLeaf|SpanNode|) span
Parameters:
MarkdownSpan
Returns: Choice<SpanLeafInfo, (SpanNodeInfo * MarkdownSpans)>
|
Active pattern that classifies a
|
FSharp.Formatting