ParamKeys Module
Defines the parameter keys known to FSharp.Formatting processing code
Functions and values
| Function or value |
Description
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting, either 'content' or 'api-doc' Mean to be used on the `class` attribute in the ` ` tag. This helps to differentiate styles between API docs and custom content.
|
|
A parameter key known to FSharp.Formatting, available when `_head.html` exists in the input folder.
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting, available when `_head.html` exists in the input folder.
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting, available in _menu_template.html This will be an empty string if the category is not active.
|
|
A parameter key known to FSharp.Formatting, available in _menu_template.html
|
|
A parameter key known to FSharp.Formatting, available in _menu_template.html
|
|
A parameter key known to FSharp.Formatting, available in _menu-item_template.html /// This will be an empty string if the item is not active.
|
|
A parameter key known to FSharp.Formatting, available in _menu-item_template.html
|
|
A parameter key known to FSharp.Formatting, available in _menu-item_template.html
|
|
A parameter key known to FSharp.Formatting, available in _menu-item_template.html
|
|
A parameter key known to FSharp.Formatting, available in _menu-item_template.html This will be an empty string if the item has no hover text of its own.
|
|
A parameter key known to FSharp.Formatting, available in _menu_template.html
|
|
A parameter key known to FSharp.Formatting, it is HTML composed from additional frontmatter information. Such as tags and description This can be empty when both properties are not provided for the current page.
|
|
A parameter key known to FSharp.Formatting, available when frontmatter is used correctly
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting, available when frontmatter is used correctly
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
The absolute URL of the site (e.g. 'https://fsprojects.github.io/FSharp.Formatting/'), for the links that must be absolute: Open Graph metadata, canonical links, llms.txt.
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
A parameter key known to FSharp.Formatting
|
|
The relative path from the page to the root of the site, ending with '/' (e.g. './' or '../../'), so that '{{root}}content/x.css' works wherever the site is hosted.
|
FSharp.Formatting