ToolTipSpan Type
A tool tip span can be emphasized text, plain text Literal, a classified Token or a line break
Union cases
| Union case |
Description
|
|
|
Full Usage:
HardLineBreak
|
|
|
|
|
FSharp.Formatting