TypeScriptFormat Type
Generates color-coded HTML 4.01 from TypeScript source code.
Constructors
| Constructor |
Description
|
Full Usage:
TypeScriptFormat()
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Keywords
Returns: string
Modifiers: abstract |
The list of TypeScript keywords extends the ones from JavaScript.
|
Inherited members
Inherited from
JavaScriptFormat
Instance members
| Instance member |
Description
|
Full Usage:
this.Keywords
Returns: string
Modifiers: abstract |
The list of JavaScript keywords.
|
Full Usage:
this.Preprocessors
Returns: string
Modifiers: abstract |
Use the pre-processor color to mark directives that start with @.
|
Full Usage:
this.Operators
Returns: string
Modifiers: abstract |
TBD
|
Inherited from
CLikeFormat
Instance members
| Instance member |
Description
|
Full Usage:
this.CommentRegEx
Returns: string
Modifiers: abstract |
Regular expression string to match single line and multi-line comments (// and /* */).
|
Full Usage:
this.StringRegEx
Returns: string
Modifiers: abstract |
Regular expression string to match string and character literals.
|
Inherited from
CodeFormat
Instance members
| Instance member |
Description
|
Full Usage:
this.Keywords
Returns: string
Modifiers: abstract |
Must be overridden to provide a list of keywords defined in each language. Keywords must be separated with spaces.
|
Full Usage:
this.Operators
Returns: string
Modifiers: abstract |
Must be overridden to provide a list of operators defined in each language. Operators must be separated with spaces.
|
Full Usage:
this.Preprocessors
Returns: string
Modifiers: abstract |
Can be overridden to provide a list of preprocessors defined in each language. Preprocessors must be separated with spaces.
|
Full Usage:
this.StringRegEx
Returns: string
Modifiers: abstract |
Must be overridden to provide a regular expression string to match strings literals.
|
Full Usage:
this.CommentRegEx
Returns: string
Modifiers: abstract |
Must be overridden to provide a regular expression string to match comments.
|
Full Usage:
this.NumberRegEx
Returns: string
Modifiers: abstract |
Can be overridden to provide a list of tokes to be recognized as numbers.
|
Full Usage:
this.CaseSensitive
Returns: bool
Modifiers: abstract |
Determines if the language is case sensitive. A case-insensitive language formatter must override this property to return false.
|
Inherited from
SourceFormat
Instance members
| Instance member |
Description
|
Full Usage:
this.FormatCode
Parameters:
Stream
-
Source code stream.
Returns: string
A string containing the HTML formatted code.
|
Transforms a source code stream to HTML 4.01.
|
Full Usage:
this.FormatCode
Parameters:
string
Returns: string
A string containing the HTML formatted code.
|
Transforms a source code string to HTML 4.01.
|
Full Usage:
this.FormatSubCode
Parameters:
string
Returns: string
|
Allows formatting a part of the code in a different language, for example a JavaScript block inside an HTML file.
|
Full Usage:
this.TabSpaces
Returns: byte
|
Gets or sets the tabs width.
|
Full Usage:
this.LineNumbers
Returns: bool
|
Enables or disables line numbers in output.
|
Full Usage:
this.Alternate
Returns: bool
|
Enables or disables alternating line background.
|
Full Usage:
this.EmbedStyleSheet
Returns: bool
|
Enables or disables the embedded CSS style sheet.
|
|
The regular expression used to capture language tokens.
|
Static members
| Static member |
Description
|
|
|
Full Usage:
SourceFormat.GetCssString()
Returns: string
A string containing the CSS definitions.
|
Gets the CSS stylesheet as a string.
|
Full Usage:
SourceFormat.EscapeHtml(str, tabSpaces)
Parameters:
string
tabSpaces : int
Returns: string
|
TBD
|
FSharp.Formatting